=================
Unchained utils
=================
This is a package for all useful utils used in unchained organization


Quick start
-----------

1. Install the lib: 

     pip install unchained-utils

2. This lib doesnt install any dependency, so you have to add what's needed in your project dependencies.
